@@ -113,19 +113,19 @@ sub update {
     my ($self, %wheres) = @_;
     
     my $sql = undef;
-    for(keys @{$self->keys}){
+    for(my $i=0; $i<scalar(@{$self->keys}); $i++){
         unless($sql){
             $sql = 'UPDATE ' . $self->table . ' SET ';
-            if (${$self->type}[$_]) {
-                $sql .= ${$self->keys}[$_] . ' ' . ${$self->type}[$_] . ' ?';
+            if (${$self->type}[$i]) {
+                $sql .= ${$self->keys}[$i] . ' ' . ${$self->type}[$i] . ' ?';
             }else{
-                $sql .= ${$self->keys}[$_] . ' = ?';
+                $sql .= ${$self->keys}[$i] . ' = ?';
             }
         }else{
-            if (${$self->type}[$_]) {
-                $sql .= ', ' . ${$self->keys}[$_] . ' ' . ${$self->type}[$_] . ' ?';
+            if (${$self->type}[$i]) {
+                $sql .= ', ' . ${$self->keys}[$i] . ' ' . ${$self->type}[$i] . ' ?';
             }else{
-                $sql .= ', ' . ${$self->keys}[$_] . ' = ?';
+                $sql .= ', ' . ${$self->keys}[$i] . ' = ?';
             }
         }
     }
